<?php 
    add_theme_support( 'post-thumbnails' );

    register_nav_menus(
        array('primary-menu'=>'Top Menu')
    );

    function options() {
    acf_add_options_page();
    }
    add_action('init', 'options');
 
 
 function mytheme_add_woocommerce_support() {
    add_theme_support('woocommerce');
}
add_action('after_setup_theme', 'mytheme_add_woocommerce_support');


function enqueue_woocommerce_ajax() {
    if (function_exists('wc_enqueue_js')) {
        wc_enqueue_js("
            jQuery('.add_to_cart_button').on('click', function(e) {
                e.preventDefault();
            });
        ");
    }
}
add_action('wp_enqueue_scripts', 'enqueue_woocommerce_ajax');


function enable_ajax_add_to_cart() {
    add_theme_support( 'wc-product-gallery-zoom' );
    add_theme_support( 'wc-product-gallery-lightbox' );
    add_theme_support( 'wc-product-gallery-slider' );
}
add_action( 'after_setup_theme', 'enable_ajax_add_to_cart' );



// Add custom fields to WooCommerce registration form
function custom_woocommerce_registration_fields() {
    ?>
    <p class="form-row form-row-wide">
        <label for="reg_billing_first_name"><?php esc_html_e( 'Full Name', 'woocommerce' ); ?> <span class="required">*</span></label>
        <input type="text" class="input-text" name="billing_first_name" id="reg_billing_first_name" value="<?php if ( ! empty( $_POST['billing_first_name'] ) ) echo esc_attr( wp_unslash( $_POST['billing_first_name'] ) ); ?>" required/>
    </p>
    
    <p class="form-row form-row-wide">
        <label for="reg_billing_phone"><?php esc_html_e( 'Mobile No.', 'woocommerce' ); ?> <span class="required">*</span></label>
        <input type="tel" class="input-text" name="billing_phone" id="reg_billing_phone" value="<?php if ( ! empty( $_POST['billing_phone'] ) ) echo esc_attr( wp_unslash( $_POST['billing_phone'] ) ); ?>" required/>
    </p>
    
    <p class="form-row form-row-wide">
        <label for="reg_password"><?php esc_html_e( 'Password', 'woocommerce' ); ?> <span class="required">*</span></label>
        <input type="password" class="input-text" name="password" id="reg_password" required/>
    </p>

    <p class="form-row form-row-wide">
        <label for="reg_confirm_password"><?php esc_html_e( 'Confirm Password', 'woocommerce' ); ?> <span class="required">*</span></label>
        <input type="password" class="input-text" name="confirm_password" id="reg_confirm_password" required/>
    </p>
    <?php
}
add_action( 'woocommerce_register_form_start', 'custom_woocommerce_registration_fields' );


// Validate new fields during registration
function custom_validate_registration_fields( $errors, $username, $email ) {
    if ( empty( $_POST['billing_first_name'] ) ) {
        $errors->add( 'first_name_error', __( '<strong>Error:</strong> Full Name is required.', 'woocommerce' ) );
    }
    if ( empty( $_POST['billing_phone'] ) ) {
        $errors->add( 'phone_error', __( '<strong>Error:</strong> Mobile No. is required.', 'woocommerce' ) );
    }
    if ( empty( $_POST['password'] ) ) {
        $errors->add( 'password_error', __( '<strong>Error:</strong> Password is required.', 'woocommerce' ) );
    }
    if ( empty( $_POST['confirm_password'] ) ) {
        $errors->add( 'confirm_password_error', __( '<strong>Error:</strong> Confirm Password is required.', 'woocommerce' ) );
    }
    if ( ! empty( $_POST['password'] ) && ! empty( $_POST['confirm_password'] ) && $_POST['password'] !== $_POST['confirm_password'] ) {
        $errors->add( 'password_mismatch', __( '<strong>Error:</strong> Passwords do not match.', 'woocommerce' ) );
    }
    return $errors;
}
add_filter( 'woocommerce_registration_errors', 'custom_validate_registration_fields', 10, 3 );


// Save the custom fields in user meta
function custom_save_registration_fields( $customer_id ) {
    if ( isset( $_POST['billing_first_name'] ) ) {
        update_user_meta( $customer_id, 'billing_first_name', sanitize_text_field( $_POST['billing_first_name'] ) );
    }
    if ( isset( $_POST['billing_phone'] ) ) {
        update_user_meta( $customer_id, 'billing_phone', sanitize_text_field( $_POST['billing_phone'] ) );
    }
    if ( isset( $_POST['password'] ) && ! empty( $_POST['password'] ) ) {
        wp_set_password( $_POST['password'], $customer_id );
    }
}
add_action( 'woocommerce_created_customer', 'custom_save_registration_fields' );


// Display additional fields on My Account Page
function custom_display_account_fields( $user ) {
    ?>
    <h3><?php esc_html_e( 'Additional Information', 'woocommerce' ); ?></h3>
    <table class="form-table">
        <tr>
            <th><label for="billing_first_name"><?php esc_html_e( 'Full Name', 'woocommerce' ); ?></label></th>
            <td>
                <input type="text" name="billing_first_name" id="billing_first_name" value="<?php echo esc_attr( get_user_meta( $user->ID, 'billing_first_name', true ) ); ?>" class="regular-text" />
            </td>
        </tr>
        <tr>
            <th><label for="billing_phone"><?php esc_html_e( 'Mobile No.', 'woocommerce' ); ?></label></th>
            <td>
                <input type="text" name="billing_phone" id="billing_phone" value="<?php echo esc_attr( get_user_meta( $user->ID, 'billing_phone', true ) ); ?>" class="regular-text" />
            </td>
        </tr>
    </table>
    <?php
}
add_action( 'show_user_profile', 'custom_display_account_fields' );
add_action( 'edit_user_profile', 'custom_display_account_fields' );


// Add "Buy Now" button on single product pages
add_action('woocommerce_after_add_to_cart_button', 'add_buy_now_button');

function add_buy_now_button() {
    global $product;
    $checkout_url = wc_get_checkout_url();

    if ($product->is_type('variable')) {
        ?>
        <script type="text/javascript">
            jQuery(document).ready(function($) {
                var updateBuyNowButton = function() {
                    var qty = $('input.qty').val();
                    var variation_id = $('input[name="variation_id"]').val();
                    var checkout_url = '<?php echo $checkout_url; ?>';
                    var buy_now_url = checkout_url + '?add-to-cart=<?php echo $product->get_id(); ?>';

                    if (variation_id) {
                        buy_now_url += '&variation_id=' + variation_id;
                    }

                    if (qty) {
                        buy_now_url += '&quantity=' + qty;
                    }

                    $('.buy-now-button').attr('href', buy_now_url);
                    console.log($('input[name="subscribe-to-action-input"]:checked').val());
                };

                $('body').on('change', 'input.qty, input[name="variation_id"]', function() {
                    updateBuyNowButton();
                });
               

                 $('body').on('change', 'input.wcsatt-options-prompt-action-input', function() {
                    // If the value is 'yes' (Subscribe is selected), hide the Buy Now button
                    if ($('input[name="subscribe-to-action-input"]:checked').val() === 'yes') {
                        $('.buy-now-button').hide();  // Hide the Buy Now button
                    } else {
                        $('.buy-now-button').show();  // Show the Buy Now button for one-time purchase
                    }
                    // alert('fgfdd')
                });

                // Trigger the update on page load and after selecting a variation
                $('input.qty, input[name="variation_id"]').on('change', function() {
                    updateBuyNowButton();
                });

                $('.variations_form').on('woocommerce_variation_select_change', function() {
                    updateBuyNowButton();
                });

                // Initial trigger
                updateBuyNowButton();
            });
        </script>
        <a href="#" class="buy-now-button button alt">Buy Now</a>
        <?php
    } else {
        $product_id = $product->get_id();
        ?>
        <script type="text/javascript">
            jQuery(document).ready(function($) {
                 $('body').on('change', 'input.wcsatt-options-prompt-action-input', function() {
                    // If the value is 'yes' (Subscribe is selected), hide the Buy Now button
                    if ($('input[name="subscribe-to-action-input"]:checked').val() === 'yes') {
                        $('.buy-now-button').hide();  // Hide the Buy Now button
                    } else {
                        $('.buy-now-button').show();  // Show the Buy Now button for one-time purchase
                    }
                    // alert('fgfdd')
                });
                $('body').on('change', 'input.qty', function() {
                    var qty = $(this).val();
                    var product_id = <?php echo $product_id; ?>;
                    var checkout_url = '<?php echo $checkout_url; ?>';
                    var buy_now_url = checkout_url + '?add-to-cart=' + product_id + '&quantity=' + qty;

                    $('.buy-now-button').attr('href', buy_now_url);
                });

                // Trigger the change event on page load to set the initial quantity
                $('input.wcsatt-options-prompt-action-input').trigger('change');
                $('input.qty').trigger('change');
            });
        </script>
        <a href="<?php echo esc_url($checkout_url . '?add-to-cart=' . $product_id); ?>" class="buy-now-button button alt">Buy Now</a>
        <?php
    }
}

// Shortcode to display WooCommerce cart count
function woo_cart_count_shortcode() {
    return WC()->cart->get_cart_contents_count();
}
add_shortcode('woo_cart_count', 'woo_cart_count_shortcode');


// Remove "Downloads" menu item from My Account page
add_filter( 'woocommerce_account_menu_items', 'remove_downloads_my_account', 999 );
function remove_downloads_my_account( $items ) {
    unset($items['downloads']);
    return $items;
}
